@@ -5,7 +5,7 @@ package App::Greple::md;
 use 5.024;
 use warnings;
 
-our $VERSION = "0.99";
+our $VERSION = "0.9901";
 
 =encoding utf-8
 
@@ -19,60 +19,91 @@ App::Greple::md - Greple module for Markdown syntax highlighting
 
     greple -Mmd --mode=dark -- file.md
 
-    greple -Mmd --hashed h3=1 -- file.md
+    greple -Mmd --base-color=Crimson -- file.md
 
     greple -Mmd --cm h1=RD -- file.md
 
+    greple -Mmd --no-table -- file.md
+
 =head1 DESCRIPTION
 
-B<App::Greple::md> is a L<greple|App::Greple> module that provides
-Markdown syntax highlighting with cumulative coloring for nested
-elements (e.g., links inside headings).
+B<App::Greple::md> is a L<greple|App::Greple> module for viewing
+Markdown files in the terminal with syntax highlighting.
 
-Patterns are processed in priority order: code block state machine,
-inline code protection, HTML comment protection, links with OSC 8
-hyperlinks, headings (cumulative), emphasis (bold, italic,
-strikethrough), blockquotes, and horizontal rules.
+It colorizes headings, bold, italic, strikethrough, inline code,
+fenced code blocks, HTML comments, blockquotes, horizontal rules,
+links, and images.  Tables are formatted with aligned columns and
+optional Unicode box-drawing borders.  Links become clickable via
+OSC 8 terminal hyperlinks in supported terminals.
+
+Nested elements are handled with cumulative coloring: for example,
+a link inside a heading retains both its link color and the heading
+background color.
+
+For a complete Markdown viewing experience with line folding,
+multi-column output, and themes, see L<App::mdee>, which uses this
+module as its highlighting engine.
 
 =head1 MODULE OPTIONS
 
-These options are specified before C<--> to separate them from
-greple options:
+Module options are specified before C<--> to separate them from
+greple's own options:
 
     greple -Mmd --mode=dark --cm h1=RD -- file.md
 
-=head2 B<--mode>=I<MODE>
+=head2 B<-m> I<MODE>, B<--mode>=I<MODE>
 
-Set color mode to C<light> (default) or C<dark>.
+Set color mode.  Available modes are C<light> (default) and C<dark>.
 
-    greple -Mmd --mode=dark -- file.md
+    greple -Mmd -m dark -- file.md
 
-=head2 B<--base-color>=I<COLOR>
+=head2 B<-B> I<COLOR>, B<--base-color>=I<COLOR>
 
-Override the base color used for headings, bold, links, etc.
-Accepts a color name (e.g., C<Crimson>, C<DarkCyan>) or a
+Override the base color used for headings, bold, links, and other
+elements.  Accepts a named color (e.g., C<Crimson>, C<DarkCyan>) or a
 L<Term::ANSIColor::Concise> color spec.
 
-    greple -Mmd --base-color=Crimson -- file.md
+    greple -Mmd -B Crimson -- file.md
+
+=head2 B<--[no-]table>
+
+Enable or disable table formatting.  When enabled (default),
+Markdown tables (3 or more consecutive pipe-delimited rows) are
+formatted with aligned columns using L<App::ansicolumn>.
+
+    greple -Mmd --no-table -- file.md
+
+=head2 B<--[no-]rule>
+
+Enable or disable Unicode box-drawing characters for table borders.
+When enabled (default), ASCII pipe characters (C<|>) are replaced
+with vertical lines (C<E<0x2502>>), and separator row dashes become
+horizontal rules (C<E<0x2500>>) with corner pieces (C<E<0x251C>>,
+C<E<0x2524>>, C<E<0x253C>>).
+
+    greple -Mmd --no-rule -- file.md
 
 =head2 B<--cm> I<LABEL>=I<SPEC>
 
-Override the color for a specific label.  Color specs follow
-L<Term::ANSIColor::Concise> format and support C<sub{...}> function
-specs via L<Getopt::EX::Colormap>.
+Override the color for a specific element.  I<LABEL> is one of
+the color labels listed in L</COLOR LABELS>.  I<SPEC> follows
+L<Term::ANSIColor::Concise> format and supports C<sub{...}>
+function specs via L<Getopt::EX::Colormap>.
 
     greple -Mmd --cm h1=RD -- file.md
+    greple -Mmd --cm bold='${base}D' -- file.md
 
 =head2 B<--hashed> I<LEVEL>=I<VALUE>
 
-Add closing hashes to headings (e.g., C<### Title> becomes
-C<### Title ###>).  Can be set per heading level:
+Append closing hashes to headings.  For example, C<### Title>
+becomes C<### Title ###>.  Set per heading level:
 
     greple -Mmd --hashed h3=1 --hashed h4=1 -- file.md
 
 =head2 B<--show> I<LABEL>[=I<VALUE>]
 
-Control which elements are highlighted.
+Control which elements are highlighted.  This is useful for
+focusing on specific elements or disabling unwanted highlighting.
 
     greple -Mmd --show bold=0 -- file.md          # disable bold
     greple -Mmd --show all= --show h1 -- file.md  # only h1
@@ -83,8 +114,8 @@ C<all> is a special key that sets all labels at once.
 
 =head1 CONFIGURATION
 
-Module parameters can also be set with the C<config()> function
-in the module declaration:
+Module parameters can also be set using the C<config()> function
+in the C<-M> declaration:
 
     greple -Mmd::config(mode=dark,base_color=Crimson) file.md
 
@@ -92,52 +123,81 @@ Nested hash parameters use dot notation:
 
     greple -Mmd::config(hashed.h3=1,hashed.h4=1) file.md
 
-=head2 Table Formatting
+Available parameters:
 
-By default, Markdown tables are formatted with aligned columns using
-L<App::ansicolumn> and separator lines are converted to Unicode
-box-drawing characters.  Control with C<table> and C<rule> parameters:
-
-    greple -Mmd::config(table=0) file.md    # disable table formatting
-    greple -Mmd::config(rule=0) file.md     # disable box-drawing characters
+    mode          light or dark (default: light)
+    base_color    base color override
+    table         table formatting (default: 1)
+    rule          box-drawing characters (default: 1)
+    osc8          OSC 8 hyperlinks (default: 1)
+    hashed.h1-h6  closing hashes per level (default: 0)
 
 =head2 OSC 8 Hyperlinks
 
-By default, links are converted to OSC 8 terminal hyperlinks for
-clickable URLs in supported terminals.  Disable with:
+Links are converted to clickable OSC 8 terminal hyperlinks in
+supported terminals (iTerm2, Kitty, WezTerm, Ghostty, etc.).
+Disable with:
 
     greple -Mmd::config(osc8=0) file.md
 
 =head1 COLOR LABELS
 
-The following color labels are available for C<--cm> and C<--show>:
+The following labels identify colorizable elements.  Use them
+with C<--cm> to customize colors or C<--show> to control
+visibility.
+
+=head2 Code
 
     code_mark        Code delimiters (fences and backticks)
-    code_info        Fenced code block info string
+    code_info        Fenced code block info string (language name)
     code_block       Fenced code block body
     code_inline      Inline code body
-    comment          HTML comments
+
+=head2 Headings
+
+    h1 - h6          Heading levels 1 through 6
+
+=head2 Inline Formatting
+
+    bold             Bold (**text** or __text__)
+    italic           Italic (*text* or _text_)
+    strike           Strikethrough (~~text~~)
+
+=head2 Block Elements
+
+    blockquote       Blockquote marker (>)
+    horizontal_rule  Horizontal rules (---, ***, ___)
+    comment          HTML comments (<!-- ... -->)
+
+=head2 Links
+
     link             Inline links [text](url)
     image            Images ![alt](url)
     image_link       Image links [![alt](img)](url)
-    h1 - h6          Headings
-    bold             Bold text (**text** or __text__)
-    italic           Italic text (*text* or _text_)
-    strike           Strikethrough text (~~text~~)
-    blockquote       Blockquote marker (>)
-    horizontal_rule  Horizontal rules (---, ***, ___)
 
 =head1 SEE ALSO
 
-L<App::mdee> - Markdown viewer using this module
+=over 4
 
-L<App::Greple>
+=item L<App::mdee>
 
-L<Term::ANSIColor::Concise>
+Markdown viewer command with line folding, table formatting,
+multi-column layout, and themes.  Uses this module for syntax
+highlighting.
 
-L<Getopt::EX::Colormap>
+=item L<App::Greple>
 
-L<Getopt::EX::Config>
+General-purpose extensible grep tool that hosts this module.
+
+=item L<Term::ANSIColor::Concise>
+
+Concise ANSI color specification format used for color labels.
+
+=item L<App::ansicolumn>
+
+ANSI-aware column formatting used for table alignment.
+
+=back
 
 =head1 AUTHOR
 
@@ -176,20 +236,20 @@ my %base_color = (
 
 my %default_colors = (
     code_mark       => 'L20',
-    code_info       => '${base_name}+r60=y70',
+    code_info       => '${base_name}=y70',
     code_block      => '/L23;E',
-    code_inline     => '/L23',
+    code_inline     => 'L00/L23',
     comment         => '${base}+r60',
-    link            => '${base}',
-    image           => '${base}',
-    image_link      => '${base}',
-    h1              => 'L25DE/${base}',
-    h2              => 'L25DE/${base}+y20',
+    link            => 'I',
+    image           => 'I',
+    image_link      => 'I',
+    h1              => 'L25D/${base};E',
+    h2              => 'L25D/${base}+y20;E',
     h3              => 'L25DN/${base}+y30',
     h4              => '${base}UD',
     h5              => '${base}+y20;U',
     h6              => '${base}+y20',
-    bold            => '${base}D',
+    bold            => 'D',
     italic          => 'I',
     strike          => 'X',
     blockquote      => '${base}D',
@@ -198,11 +258,11 @@ my %default_colors = (
 
 my %dark_overrides = (
     code_mark       => 'L10',
-    code_info       => '${base_name}+r60=y20',
+    code_info       => '${base_name}=y20',
     code_block      => '/L05;E',
-    code_inline     => '/L05',
-    h1              => 'L00DE/${base}',
-    h2              => 'L00DE/${base}-y15',
+    code_inline     => 'L25/L05',
+    h1              => 'L00D/${base};E',
+    h2              => 'L00D/${base}-y15;E',
     h3              => 'L00DN/${base}-y25',
     h4              => '${base}UD',
     h5              => '${base}-y20;U',
@@ -234,7 +294,7 @@ my %show;
 sub finalize {
     my($mod, $argv) = @_;
     $config->deal_with($argv,
-                       "mode=s", "base_color=s", "table!", "rule!",
+                       "mode|m=s", "base_color|B=s", "table!", "rule!",
                        "hashed=s%",
                        "cm=s" => \@opt_cm,
                        "show=s%" => \%show);
@@ -303,21 +363,24 @@ sub md_color {
 #
 # Protection mechanism
 #
-# NUL-byte placeholders protect processed regions (inline code,
+# SGR 256 placeholders protect processed regions (inline code,
 # comments, links) from being matched by later patterns.
 #
 
 my @protected;
+my($PS, $PE) = ("\e[256m", "\e[m");     # protect start/end markers
+my $PR = qr/\e\[256m(\d+)\e\[m/;       # protect restore pattern
+my($OS, $OE) = ("\e]8;;", "\e\\");      # OSC 8 start/end markers
 
 sub protect {
     my $text = shift;
     push @protected, $text;
-    "\e[256m" . $#protected . "\e[m";
+    $PS . $#protected . $PE;
 }
 
 sub restore {
     my $s = shift;
-    $s =~ s/\e\[256m(\d+)\e\[m/$protected[$1]/g;
+    $s =~ s{$PR}{$protected[$1] // die "restore failed: index $1"}ge;
     $s;
 }
 
@@ -329,7 +392,7 @@ sub osc8 {
     return $_[1] unless $config->{osc8};
     my($url, $text) = @_;
     my $escaped = uri_escape_utf8($url, "^\\x20-\\x7e");
-    "\e]8;;${escaped}\e\\${text}\e]8;;\e\\";
+    "${OS}${escaped}${OE}${text}${OS}${OE}";
 }
 
 #
@@ -403,7 +466,7 @@ sub colorize {
     # 6. Links: [text](url) (not preceded by !)
     ############################################################
 
-    s{(?<!!)\[($LT)\]\(<?([^>)\s\n]+)>?\)}{
+    s{(?<![!\e])\[($LT)\]\(<?([^>)\s\n]+)>?\)}{
         protect(osc8($2, md_color('link', "[$1]")))
     }ge;
 
@@ -416,7 +479,33 @@ sub colorize {
     }
 
     ############################################################
-    # 8. Headings h6 -> h1 (cumulative over links)
+    # 8. Bold: **text** and __text__
+    ############################################################
+
+    if (active('bold')) {
+        s/(?<![\\`])\*\*.*?(?<!\\)\*\*/md_color('bold', $&)/ge;
+        s/(?<![\\`\w])__.*?(?<!\\)__(?!\w)/md_color('bold', $&)/ge;
+    }
+
+    ############################################################
+    # 9. Italic: _text_ and *text*
+    ############################################################
+
+    if (active('italic')) {
+        s/(?<![\\`\w])_(?:(?!_).)+(?<!\\)_(?!\w)/md_color('italic', $&)/ge;
+        s/(?<![\\`\*])\*(?:(?!\*).)+(?<!\\)\*(?!\*)/md_color('italic', $&)/ge;
+    }
+
+    ############################################################
+    # 10. Strikethrough: ~~text~~
+    ############################################################
+
+    if (active('strike')) {
+        s/(?<![\\`])~~.+?(?<!\\)~~/md_color('strike', $&)/ge;
+    }
+
+    ############################################################
+    # 11. Headings h6 -> h1 (cumulative over emphasis)
     ############################################################
 
     if (active('header')) {
@@ -428,37 +517,11 @@ sub colorize {
                 my $line = $1;
                 $line .= " $hdr"
                     if $hashed->{"h$n"} && $line !~ /\#$/;
-                md_color("h$n", $line);
+                md_color("h$n", restore($line));
             }mge;
         }
     }
 
-    ############################################################
-    # 9. Bold: **text** and __text__
-    ############################################################
-
-    if (active('bold')) {
-        s/(?<![\\`])\*\*.*?(?<!\\)\*\*/md_color('bold', $&)/ge;
-        s/(?<![\\`\w])__.*?(?<!\\)__(?!\w)/md_color('bold', $&)/ge;
-    }
-
-    ############################################################
-    # 10. Italic: _text_ and *text*
-    ############################################################
-
-    if (active('italic')) {
-        s/(?<![\\`\w])_(?:(?!_).)+(?<!\\)_(?!\w)/md_color('italic', $&)/ge;
-        s/(?<![\\`\*])\*(?:(?!\*).)+(?<!\\)\*(?!\*)/md_color('italic', $&)/ge;
-    }
-
-    ############################################################
-    # 11. Strikethrough: ~~text~~
-    ############################################################
-
-    if (active('strike')) {
-        s/(?<![\\`])~~.+?(?<!\\)~~/md_color('strike', $&)/ge;
-    }
-
     ############################################################
     # 12. Blockquote: color only the > marker
     ############################################################
